// App.java
// Justin Ludiwg 1999.03.01

package edu.wooster.lu99jp26.link;

import edu.wooster.lu99jp26.util.Function;
import edu.wooster.lu99jp26.util.RetrieveURLDialog;
import edu.wooster.lu99jp26.util.RetrieveURLListener;
import java.awt.Canvas;
import java.awt.Dimension;
import java.awt.FileDialog;
import java.awt.Font;
import java.awt.Frame;
import java.awt.Graphics;
import java.awt.Menu;
import java.awt.MenuBar;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.lang.String;
import java.lang.System;
import java.net.URL;

public class App extends Frame
implements ActionListener, RetrieveURLListener
{
	static App app;
	
	
	public static void main (String args[])
	{
		app = new App ();
	}

    /**
     * Gets the App object
     * @return App the App
     */
	public static App getApp ()
	{
		return app;
	}
	
	
	Canvas message;
	
	
	public App ()
	{
		super ();
		
		// create menubar
		Menu file = new Menu ("File");
		Function.addMenuItem (file, "Open Local...", 'O', this);
		Function.addMenuItem (file, "Retrieve From URL...", 'R', this);
		file.addSeparator ();
		Function.addMenuItem (file, "Quit", 'Q', this);
		
		MenuBar bar = new MenuBar ();
		bar.add (file);
		setMenuBar (bar);
		
		// create progress message field
		message = new Canvas ();
		message.setFont (new Font ("Helvetica", Font.BOLD, 10));
		add (message);
		
		pack ();
		show ();
	}
	
	public Dimension preferredSize ()
	{
		return new Dimension (600, 20);
	}

    /**
     * Invoked when an action occurs.
     */
	public void actionPerformed (ActionEvent e)
	{
		String command = e.getActionCommand ();
		
		if (command.startsWith ("Open"))
		{
			// put up file dialog
			FileDialog d = new FileDialog (this);
			d.setMode (FileDialog.LOAD);
			d.show ();
			
			// get user selection
			String name = d.getFile ();
			String dir = d.getDirectory ();
			d.dispose ();
			
			// if not cancelled, show the page
			if (name != null)
			{
				File file = new File (dir, name);
				if (file.exists ())
					ViewerFactory.newDefaultViewer ("file:" + dir + name);
			}
		}
		else if (command.startsWith ("Retrieve"))
			new RetrieveURLDialog (this);
		
		else if (command.equals ("Quit"))
			System.exit (0);
	}
    
    /**
	 * passes URL in String form
	 * @param url String the URL
	 */
	public void retrieveURL (String url)
	{
		ViewerFactory.newDefaultViewer (url);
	}
    
    /**
	 * sets the message label of this window
	 * @param s String the message
	 */
	public void setMessage (String s)
	{
		Graphics g = message.getGraphics ();
		Rectangle r = g.getClipBounds ();
		
		g.clearRect (r.x, r.y, r.width, r.height);
		g.drawString (s, 2, 15);
	}
}