// Function.java
// Justin Ludiwg 1999.03.01

package edu.wooster.lu99jp26.util;

import java.awt.Component;
import java.awt.Menu;
import java.awt.MenuItem;
import java.awt.MenuShortcut;
import java.awt.event.ActionListener;
import java.lang.String;
import java.lang.System;

public class Function
{
	/**
	 * makes a menu item for this popup button, and adds action listener
	 * @param menu Menu to which item is added
	 * @param name String name of the new menu item
	*/
	public static void addMenuItem (Menu menu, String name, 
									ActionListener listener)
	{
		addMenuItem (menu, name, 0, listener);
	}
	
	/**
	 * makes a menu item for this popup button, and adds action listener
	 * @param menu Menu to which item is added
	 * @param name String name of the new menu item
	 * @param key  int if greater > 0, the shortcut key for the menu
	*/
	public static void addMenuItem (Menu menu, String name, int key, 
									ActionListener listener)
	{
		MenuItem i = (key > 0 ? new MenuItem (name, new MenuShortcut (key)) 
							  : new MenuItem (name));
		
		i.setActionCommand (name);
	   	i.addActionListener (listener);
	   	
	   	menu.add (i);
	}
	
	/**
	 * finds the root container of the passed Component
	 * @param c Component component whose root we wish to find
	 * @return Component the root container (or the component if c has no parent)
	*/
	public static Component getRootContainer (Component c)
	{
		while (c.getParent () != null)
			c = c.getParent ();
		
		return c;
	}
	
	/**
	 * adds url path to local file in the user's directory
	 * @param name String the local file name or path e.g. "myDir/myFile"
	 * @return String the full url path e.g. "file:///myDrive/myDir/myFile"
	 */
	public static String userDirToURL (String name)
	{
		String dir = System.getProperty ("user.dir");
		char sep = System.getProperty ("file.separator").charAt (0);
		
		return "file:" + (sep != '/' ? "/" : "") + dir.replace (sep, '/') 
					   + "/" + name;
	}
	
	/**
	 * extracts the attribute value of a String of XML attribute-value pairs
	 * @param s String the source String
	 * @param attr String the attribute to search for
	 * @param def String default value to return
	 * @return String the value of attr
	 */
	public static String extractAttrValue (String s, String attr, String def)
	{
		int len = s.length ();
		int alen = attr.length ();
		int i, j, start, end;
		
		for (i = 0; i < len - alen; i++)
		{
			for (j = 0; j < alen; j++)
				if (s.charAt (i + j) != attr.charAt (j))
					break;
			
			// attr matched; now extract value out of quotes
			if (j == alen)
			{
				for (j = j + i; s.charAt (j) != '"' && s.charAt (j) != '\''; j++);
				start = ++j;
				for (j = j; s.charAt (j) != '"' && s.charAt (j) != '\''; j++);
				end = j;
				
				return s.substring (start, end);
			}
		}
		
		return def;
	}
	
	/**
	 * extracts the parameter value from a String function eg. "foo (a, hello, c)"
	 * @param s String the source String
	 * @param num int the parameter number eg. num of 2 returns "hello"
	 * @return String the value of parameter
	 */
	public static String extractParam (String s, int num)
	{
		int start = s.indexOf ('(') + 1;
		
		for (int i = 1; i < num; i++)
		{
			start = s.indexOf (',', start);
			// num > actual number of params
			if (start < 0)
				return "";
			start++;
		}
		
		int end = s.indexOf (',', start);
		
		if (end < 0)
			end = s.lastIndexOf (')');
		
		return s.substring (start, end).trim ();
	}
}